@@ -1,4 +1,5 @@
 import logging
+from datetime import timedelta
 
 from django.apps import apps
 from django.contrib.contenttypes.models import ContentType
@@ -236,7 +237,7 @@ class DataCheckRegistry:
         return [(check.name, check.verbose_name) for check in cls.data_checks]
 
 
-@recorded_task
+@recorded_task(run_every=timedelta(minutes=15))
 def check_data(recorder: ProgressRecorder):
     """Execute all registered data checks and send email if activated."""
     for check in recorder.iterate(DataCheckRegistry.data_checks):
