@@ -18,6 +18,7 @@ from dj_cleavejs import CleaveWidget
 from django_select2.forms import ModelSelect2MultipleWidget, ModelSelect2Widget, Select2Widget
 from dynamic_preferences.forms import PreferenceForm
 from guardian.shortcuts import assign_perm
+from invitations.forms import InviteForm
 from material import Fieldset, Layout, Row
 
 from .mixins import ExtensibleForm, SchoolTermRelatedExtensibleForm
@@ -29,6 +30,7 @@ from .models import (
     GroupType,
     OAuthApplication,
     Person,
+    PersonInvitation,
     SchoolTerm,
 )
 from .registries import (
@@ -353,7 +355,7 @@ class EditGroupTypeForm(forms.ModelForm):
 
     class Meta:
         model = GroupType
-        exclude = []
+        fields = ["name", "description"]
 
 
 class SchoolTermForm(ExtensibleForm):
@@ -410,6 +412,31 @@ class InvitationCodeForm(forms.Form):
         self.fields["code"].widget = CleaveWidget(blocks=blocks, delimiter="-", uppercase=True)
 
 
+class PersonCreateInviteForm(InviteForm):
+    """Custom form to create a person and invite them."""
+
+    first_name = forms.CharField(label=_("First name"), required=True)
+    last_name = forms.CharField(label=_("Last name"), required=True)
+
+    layout = Layout(
+        Row("first_name", "last_name"),
+        Row("email"),
+    )
+
+    def clean_email(self):
+        if Person.objects.filter(email=self.cleaned_data["email"]).exists():
+            raise ValidationError(_("A person is using this e-mail address"))
+        return super().clean_email()
+
+    def save(self, email):
+        person = Person.objects.create(
+            first_name=self.cleaned_data["first_name"],
+            last_name=self.cleaned_data["last_name"],
+            email=email,
+        )
+        return PersonInvitation.create(email=email, person=person)
+
+
 class SelectPermissionForm(forms.Form):
     """Select a permission to assign."""
 
@@ -597,6 +624,7 @@ class AccountRegisterForm(SignupForm, ExtensibleForm):
 
             if person:
                 available_fields = [field.name for field in Person._meta.get_fields()]
+                self.fields["email2"].initial = person.email
                 for field in self.fields:
                     if field in available_fields and getattr(person, field):
                         self.fields[field].disabled = True
