@@ -20,6 +20,15 @@ MENUS = {
                 ("aleksis.core.util.predicates.permission_validator", "core.can_register"),
             ],
         },
+        {
+            "name": _("Accept invitation"),
+            "url": "enter_invitation_code",
+            "icon": "vpn_key",
+            "validators": [
+                "menu_generator.validators.is_anonymous",
+                ("aleksis.core.util.predicates.permission_validator", "core.invite_enabled"),
+            ],
+        },
         {
             "name": _("Dashboard"),
             "url": "index",
@@ -183,17 +192,6 @@ MENUS = {
                         ),
                     ],
                 },
-                {
-                    "name": _("Impersonation"),
-                    "url": "impersonate-list",
-                    "icon": "people",
-                    "validators": [
-                        (
-                            "aleksis.core.util.predicates.permission_validator",
-                            "core.impersonate_rule",
-                        ),
-                    ],
-                },
                 {
                     "name": _("Configuration"),
                     "url": "preferences_site",
@@ -307,6 +305,15 @@ MENUS = {
                         )
                     ],
                 },
+                {
+                    "name": _("Invite person"),
+                    "url": "invite_person",
+                    "icon": "card_giftcard",
+                    "validators": [
+                        "menu_generator.validators.is_authenticated",
+                        ("aleksis.core.util.predicates.permission_validator", "core.can_invite"),
+                    ],
+                },
             ],
         },
     ],
