@@ -316,7 +316,7 @@ class Person(ExtensibleModel):
     def initials(self):
         return f"{self.first_name[0]}{self.last_name[0]}".upper()
 
-    user_info_tracker = FieldTracker(fields=("first_name", "last_name", "email"))
+    user_info_tracker = FieldTracker(fields=("first_name", "last_name", "email", "user_id"))
 
     @property
     def member_of_recursive(self) -> QuerySet:
@@ -336,16 +336,29 @@ class Person(ExtensibleModel):
 
     def save(self, *args, **kwargs):
         # Determine all fields that were changed since last load
-        dirty = self.pk is None or bool(self.user_info_tracker.changed())
+        changed = self.user_info_tracker.changed()
 
         super().save(*args, **kwargs)
 
-        if self.user and dirty:
-            # Synchronise user fields to linked User object to keep it up to date
-            self.user.first_name = self.first_name
-            self.user.last_name = self.last_name
-            self.user.email = self.email
-            self.user.save()
+        if self.pk is None or bool(changed):
+            if "user_id" in changed:
+                # Clear groups of previous Django user
+                previous_user = changed["user_id"]
+                if previous_user is not None:
+                    get_user_model().objects.get(pk=previous_user).groups.clear()
+
+            if self.user:
+                if "first_name" in changed or "last_name" in changed or "email" in changed:
+                    # Synchronise user fields to linked User object to keep it up to date
+                    self.user.first_name = self.first_name
+                    self.user.last_name = self.last_name
+                    self.user.email = self.email
+                    self.user.save()
+
+                if "user_id" in changed:
+                    # Synchronise groups to Django groups
+                    for group in self.member_of.union(self.owner_of.all()).all():
+                        group.save(force=True)
 
         # Select a primary group if none is set
         self.auto_select_primary_group()
@@ -1069,7 +1082,7 @@ class SitePreferenceModel(PerInstancePreferenceModel, PureDjangoModel):
 
     instance = models.ForeignKey(Site, on_delete=models.CASCADE)
 
-    class Meta:
+    class Meta(PerInstancePreferenceModel.Meta):
         app_label = "core"
 
 
@@ -1078,7 +1091,7 @@ class PersonPreferenceModel(PerInstancePreferenceModel, PureDjangoModel):
 
     instance = models.ForeignKey(Person, on_delete=models.CASCADE)
 
-    class Meta:
+    class Meta(PerInstancePreferenceModel.Meta):
         app_label = "core"
 
 
@@ -1087,7 +1100,7 @@ class GroupPreferenceModel(PerInstancePreferenceModel, PureDjangoModel):
 
     instance = models.ForeignKey(Group, on_delete=models.CASCADE)
 
-    class Meta:
+    class Meta(PerInstancePreferenceModel.Meta):
         app_label = "core"
 
 
@@ -1137,8 +1150,16 @@ class PersonInvitation(AbstractBaseInvitation, PureDjangoModel):
     def __str__(self) -> str:
         return f"{self.email} ({self.inviter})"
 
-    key_expired = Invitation.key_expired
+    @classmethod
+    def create(cls, email, inviter=None, **kwargs):
+        length = get_site_preferences()["auth__invite_code_length"]
+        packet_size = get_site_preferences()["auth__invite_code_packet_size"]
+        code = generate_random_code(length, packet_size)
 
+        instance = cls.objects.create(email=email, inviter=inviter, key=code, **kwargs)
+        return instance
+
+    key_expired = Invitation.key_expired
     send_invitation = Invitation.send_invitation
 
 
