@@ -12,6 +12,7 @@ from .util.core_helpers import get_app_packages, merge_app_settings, monkey_patc
 monkey_patch()
 
 IN_PYTEST = "PYTEST_CURRENT_TEST" in os.environ or "TOX_ENV_DIR" in os.environ
+PYTEST_SETUP_DATABASES = [("default", "default_oot")]
 
 ENVVAR_PREFIX_FOR_DYNACONF = "ALEKSIS"
 DIRS_FOR_DYNACONF = ["/etc/aleksis"]
@@ -203,7 +204,7 @@ TEMPLATES = [
 
 # Attention: The following context processors must accept None
 # as first argument (in addition to a HttpRequest object)
-PDF_CONTEXT_PROCESSORS = [
+NON_REQUEST_CONTEXT_PROCESSORS = [
     "django.template.context_processors.i18n",
     "django.template.context_processors.tz",
     "aleksis.core.util.core_helpers.custom_information_processor",
@@ -227,6 +228,13 @@ DATABASES = {
     }
 }
 
+# Duplicate default database for out-of-transaction updates
+DATABASES["default_oot"] = DATABASES["default"].copy()
+DATABASE_ROUTERS = [
+    "aleksis.core.util.core_helpers.OOTRouter",
+]
+DATABASE_OOT_LABELS = ["django_celery_results"]
+
 merge_app_settings("DATABASES", DATABASES, False)
 
 REDIS_HOST = _settings.get("redis.host", "localhost")
@@ -263,8 +271,9 @@ else:
 INSTALLED_APPS.append("cachalot")
 DEBUG_TOOLBAR_PANELS.append("cachalot.panels.CachalotPanel")
 CACHALOT_TIMEOUT = _settings.get("caching.cachalot.timeout", None)
-CACHALOT_DATABASES = set(["default"])
+CACHALOT_DATABASES = set(["default", "default_oot"])
 SILENCED_SYSTEM_CHECKS += ["cachalot.W001"]
+CACHALOT_ENABLED = _settings.get("caching.query_caching", True)
 
 SESSION_ENGINE = "django.contrib.sessions.backends.cache"
 SESSION_CACHE_ALIAS = "default"
@@ -363,6 +372,8 @@ INVITATIONS_INVITATION_EXPIRY = _settings.get("auth.invitation.expiry", 3)
 INVITATIONS_EMAIL_SUBJECT_PREFIX = ACCOUNT_EMAIL_SUBJECT_PREFIX
 # Use custom invitation model
 INVITATIONS_INVITATION_MODEL = "core.PersonInvitation"
+# Use custom invitation form
+INVITATIONS_INVITE_FORM = "aleksis.core.forms.PersonCreateInviteForm"
 # Display error message if invitation code is invalid
 INVITATIONS_GONE_ON_ACCEPT_ERROR = False
 # Mark invitation as accepted after signup
@@ -539,18 +550,18 @@ MEDIA_ROOT = _settings.get("media.root", os.path.join(BASE_DIR, "media"))
 NODE_MODULES_ROOT = _settings.get("node_modules.root", os.path.join(BASE_DIR, "node_modules"))
 
 YARN_INSTALLED_APPS = [
-    "cleave.js",
-    "@fontsource/roboto",
-    "jquery",
-    "@materializecss/materialize",
-    "material-design-icons-iconfont",
-    "select2",
-    "select2-materialize",
-    "paper-css",
-    "jquery-sortablejs",
-    "sortablejs",
-    "@sentry/tracing",
-    "luxon",
+    "cleave.js@^1.6.0",
+    "@fontsource/roboto@^4.5.5",
+    "jquery@^3.6.0",
+    "@materializecss/materialize@~1.0.0",
+    "material-design-icons-iconfont@^6.6.0",
+    "select2@^4.1.0-rc.0",
+    "select2-materialize@^0.1.8",
+    "paper-css@^0.4.1",
+    "jquery-sortablejs@^1.0.1",
+    "sortablejs@^1.15.0",
+    "@sentry/tracing@^6.19.6",
+    "luxon@^2.3.2",
 ]
 
 merge_app_settings("YARN_INSTALLED_APPS", YARN_INSTALLED_APPS, True)
@@ -704,7 +715,7 @@ if _settings.get("dev.uwsgi.celery", DEBUG):
     UWSGI["attach-daemon"].append("celery -A aleksis.core beat")
 
 DEFAULT_FAVICON_PATHS = {
-    "pwa_icon": os.path.join(STATIC_ROOT, "img/aleksis-icon.png"),
+    "pwa_icon": os.path.join(STATIC_ROOT, "img/aleksis-icon-maskable.png"),
     "favicon": os.path.join(STATIC_ROOT, "img/aleksis-favicon.png"),
 }
 PWA_ICONS_CONFIG = {
