@@ -15,7 +15,7 @@ def send_email(
     **kwargs,
 ):
     """Send templated email with data from context processors."""
-    processed_context = process_custom_context_processors(settings.PDF_CONTEXT_PROCESSORS)
+    processed_context = process_custom_context_processors(settings.NON_REQUEST_CONTEXT_PROCESSORS)
     processed_context.update(context)
     if not from_email:
         from_address = get_site_preferences()["mail__address"]
