@@ -1,5 +1,6 @@
 import os
 import subprocess  # noqa
+from datetime import timedelta
 from tempfile import TemporaryDirectory
 from typing import Optional, Tuple, Union
 from urllib.parse import urljoin
@@ -73,13 +74,17 @@ def generate_pdf_from_template(
 ) -> Tuple[PDFFile, AsyncResult]:
     """Start a PDF generation task and return the matching file object and Celery result."""
     if not request:
-        processed_context = process_custom_context_processors(settings.PDF_CONTEXT_PROCESSORS)
+        processed_context = process_custom_context_processors(
+            settings.NON_REQUEST_CONTEXT_PROCESSORS
+        )
         processed_context.update(context)
     else:
         processed_context = context
     html_template = render_to_string(template_name, processed_context, request)
 
-    file_object = PDFFile.objects.create(html_file=ContentFile(html_template, name="source.html"))
+    file_object = PDFFile.objects.create(
+        html_file=ContentFile(html_template.encode(), name="source.html")
+    )
 
     # As this method may be run in background and there is no request available,
     # we have to use a predefined URL from settings then
@@ -127,7 +132,7 @@ def clean_up_expired_pdf_files() -> None:
     PDFFile.objects.filter(expires_at__lt=timezone.now()).delete()
 
 
-@app.task
+@app.task(run_every=timedelta(days=1))
 def clean_up_expired_pdf_files_task() -> None:
     """Clean up expired PDF files."""
     return clean_up_expired_pdf_files()
