@@ -175,6 +175,7 @@ class ManifestView(View):
             {
                 "src": favicon_img.faviconImage.url,
                 "sizes": f"{favicon_img.size}x{favicon_img.size}",
+                "purpose": "maskable any" if prefs["theme__pwa_icon_maskable"] else "any",
             }
             for favicon_img in pwa_imgs
         ]
@@ -329,6 +330,9 @@ def person(request: HttpRequest, id_: Optional[int] = None) -> HttpResponse:
     # Get groups where person is member of
     context["groups"] = person.member_of.all()
 
+    # Get whether the invitation feature is enabled in the preferences
+    context["invite_enabled"] = get_site_preferences()["auth__invite_enabled"]
+
     return render(request, "core/person/full.html", context)
 
 
@@ -1074,6 +1078,11 @@ class InvitePerson(PermissionRequiredMixin, SingleTableView, SendInvite):
     table_class = InvitationsTable
     context = {}
 
+    def dispatch(self, request, *args, **kwargs):
+        if not get_site_preferences()["auth__invite_enabled"]:
+            return HttpResponseRedirect(reverse_lazy("invite_disabled"))
+        return super().dispatch(request, *args, **kwargs)
+
     # Get queryset of invitations
     def get_context_data(self, **kwargs):
         queryset = kwargs.pop("object_list", None)
@@ -1101,6 +1110,7 @@ class EnterInvitationCode(FormView):
             accept_invitation(
                 invitation=invitation, request=self.request, signal_sender=self.request.user
             )
+            self.request.session["invitation_code_entered"] = True
             return redirect("account_signup")
         return redirect("invitations:accept-invite", code)
 
@@ -1405,11 +1415,13 @@ class AccountRegisterView(SignupView):
     """
 
     form_class = AccountRegisterForm
-    success_url = "index"
+    success_url = reverse_lazy("index")
 
     def dispatch(self, request, *args, **kwargs):
-        if not request.user.has_perm("core.can_register") and not request.session.get(
-            "account_verified_email"
+        if (
+            not request.user.has_perm("core.can_register")
+            and not request.session.get("account_verified_email")
+            and not request.session.get("invitation_code_entered")
         ):
             raise PermissionDenied()
         return super(AccountRegisterView, self).dispatch(request, *args, **kwargs)
@@ -1420,17 +1432,22 @@ class AccountRegisterView(SignupView):
         return kwargs
 
 
-class InvitePersonByID(View):
+class InvitePersonByID(PermissionRequiredMixin, SingleObjectMixin, View):
     """Custom view to invite person by their ID."""
 
+    model = Person
     success_url = reverse_lazy("persons")
+    permission_required = "core.can_invite"
+
+    def dispatch(self, request, *args, **kwargs):
+        if not get_site_preferences()["auth__invite_enabled"]:
+            return HttpResponseRedirect(reverse_lazy("invite_disabled"))
+        return super().dispatch(request, *args, **kwargs)
 
     def get(self, request, *args, **kwargs):
-        self.object = self.get_object()
-        success_url = reverze_lazy("person_by_id", self.object.pk)
-        person = self.object
+        person = self.get_object()
 
-        if not PersonInvitation.objects.filter(email=person.email).exists():
+        if not person.email or not PersonInvitation.objects.filter(email=person.email).exists():
             length = get_site_preferences()["auth__invite_code_length"]
             packet_size = get_site_preferences()["auth__invite_code_packet_size"]
             key = generate_random_code(length, packet_size)
@@ -1441,11 +1458,37 @@ class InvitePersonByID(View):
             invite.save()
 
             invite.send_invitation(self.request)
-            messages.success(self.request, _("Person was invited successfully."))
+
+            if person.email:
+                messages.success(
+                    self.request,
+                    _(
+                        "Person was invited successfully and an email "
+                        "with further instructions has been send to them."
+                    ),
+                )
+            else:
+                readable_key = "-".join(wrap(key, packet_size))
+                messages.success(
+                    self.request,
+                    f"{_('Person was invited successfully. Their key is')} {readable_key}.",
+                )
         else:
             messages.success(self.request, _("Person was already invited."))
 
-        return HttpResponseRedirect(success_url)
+        return HttpResponseRedirect(person.get_absolute_url())
+
+
+class InviteDisabledView(PermissionRequiredMixin, TemplateView):
+    """View to display a notice that the invite feature is disabled and how to enable it."""
+
+    template_name = "invitations/disabled.html"
+    permission_required = "core.change_site_preferences_rule"
+
+    def dispatch(self, request, *args, **kwargs):
+        if get_site_preferences()["auth__invite_enabled"]:
+            raise PermissionDenied()
+        return super().dispatch(request, *args, **kwargs)
 
 
 class LoginView(AllAuthLoginView):
